pygeodesy.solveBase._SolveGDictLineBase

Package pygeodesy :: Module solveBase :: Class _SolveGDictLineBase |
[frames] | no frames]

# Class _SolveGDictLineBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
              _SolveCapsBase --+
                               |
                      _SolveBase --+
                                   |
                         _Solve3Base --+
                                       |
                         _SolveGDictBase --+
                                           |
                                          _SolveGDictLineBase

Known Subclasses:
  - geodsolve.GeodesicLineSolve
  - , rhumb.solve.RhumbLineSolve

(NTERNAL) Base class for `GeodesicLineSolve` and `RhumbLineSolve`.

Instance Methods
__init__(self, solve, lat1, lon1, caps, **azi_name) New `Solve` instance. |
toStr(self, **prec_sep_other) Return this `_LineSolve` as string. |
Inherited from `_SolveGDictBase`: `ArcDirect`, `Direct`, `Inverse`, `Inverse1` Inherited from `_SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| datum Get the datum (`Datum`).
| ellipsoid Get the ellipsoid (`Ellipsoid`).
| lat1 Get the latitude of the first point (`degrees`).
| lon1 Get the longitude of the first point (`degrees`).
Inherited from `_SolveBase`: `reverse2`, `unroll` Inherited from `_SolveCapsBase`: `Exact`, `a`, `b`, `f`, `flattening`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, solve, lat1, lon1, caps, **azi_name) (Constructor) |
New `Solve` instance. Arguments: `a_ellipsoid` - An ellipsoid (Ellipsoid) or datum (Datum) or the equatorial radius of the ellipsoid (`scalar`, conventionally in `meter`), see `f`. `f` - The flattening of the ellipsoid (`scalar`) if `a_ellipsoid` is specified as `scalar`. `path` - Optionally, the (fully qualified) path to the `GeodSolve` or `RhumbSolve` executable (`filename`). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `a_ellipsoid` or `f`. Overrides: object.__init__ (inherited documentation)

### toStr (self, **prec_sep_other) |
Return this `_LineSolve` as string. Arguments: `prec_sep` - See toStr. Overrides: named._Named.toStr

Property Details

### datum Get the datum (`Datum`). Get method: datum(self) - Get the datum (`Datum`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ellipsoid Get the ellipsoid (`Ellipsoid`). Get method: ellipsoid(self) - Get the ellipsoid (`Ellipsoid`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat1 Get the latitude of the first point (`degrees`). Get method: lat1(self) - Get the latitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lon1 Get the longitude of the first point (`degrees`). Get method: lon1(self) - Get the longitude of the first point (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.